@@ -5,8 +5,6 @@ use warnings;
 
 use Test::More;
 
-use Promise::ES6;
-
 use Net::Curl::Easy qw(:constants);
 
 use MyServer;
@@ -15,6 +13,16 @@ use constant _paths => qw( foo bar biggie baz qux quux );
 
 our $TEST_COUNT = 2 * _paths();
 
+sub sigchld_handler {
+    my $pid = waitpid -1, 1;
+    my $sig = $? & 0x7f;
+    my $exit = $? >> 8;
+
+    my $msg = "Subprocess $pid ended prematurely! (signal: $sig, exit: $exit)";
+    diag $msg;
+    die $msg;
+}
+
 sub run {
     my ($promiser, $port) = @_;
 
@@ -23,7 +31,7 @@ sub run {
         my $easy = Net::Curl::Easy->new();
         $easy->setopt( CURLOPT_URL() => "http://127.0.0.1:$port/$path" );
 
-        # $easy->setopt( CURLOPT_VERBOSE() => 1 );
+        $easy->setopt( CURLOPT_VERBOSE() => 1 );
 
         $_ = q<> for @{$easy}{ qw(_head _body) };
         $easy->setopt( CURLOPT_HEADERDATA() => \$easy->{'_head'} );
@@ -43,7 +51,11 @@ sub run {
         }, sub { warn "REJECT $path: @_\n" } );
     } _paths();
 
-    return Promise::ES6->all(\@promises);
+    my $promise_class = (ref $promises[0]);
+
+    my $is_mojo = $promise_class->isa('Mojo::Promise');
+
+    return $promise_class->all( $is_mojo ? @promises : \@promises );
 }
 
 1;
