@@ -8,14 +8,15 @@ use Test::More;
 
 use File::Temp;
 use File::Slurper;
+use Time::HiRes;
 
 our $CRLF = "\x0d\x0a";
-our $HEAD = join(
+our $HEAD_START = join(
     $CRLF,
     'HTTP/1.0 200 OK',
     'X-test: Yay',
     'Content-type: text/plain',
-    q<>, q<>,
+    q<>
 );
 
 our $BIGGIE = ('x' x 512);
@@ -26,11 +27,19 @@ sub new {
     my $dir = File::Temp::tempdir( CLEANUP => 1 );
 
     my $pid = fork or do {
-        $SIG{'CHLD'} = 'DEFAULT';
-        MyServer::HTTP->run(
-            port => 0,
-            my_tempdir => $dir,
-        );
+        local $SIG{'CHLD'};
+
+        my $ok = eval {
+            MyServer::HTTP->run(
+                port => 0,
+                my_tempdir => $dir,
+            );
+
+            1;
+        };
+
+        warn if !$ok;
+        exit( $ok ? 0 : 1 );
     };
 
     my $port;
@@ -55,15 +64,39 @@ sub port { $_[0][2] }
 sub DESTROY {
     my ($self ) = @_;
 
-    local $SIG{'CHLD'} = 'DEFAULT';
+    local $SIG{'CHLD'};
 
     my $pid = $self->[1];
 
-    diag "Destroying server (PID $pid) …";
+    my $SIG = 'QUIT';
 
-    warn if !eval { kill 'TERM', $pid; 1 };
+    diag "Destroying server (PID $pid) via SIG$SIG …";
 
-    waitpid $pid, 0;
+    my $reaped;
+
+    while ( 1 ) {
+        if (1 == waitpid $pid, 1) {
+            diag "Reaped";
+
+            $reaped = 1;
+            last;
+        }
+
+        CORE::kill($SIG, $pid) or do {
+            warn "kill($SIG, $pid): $!" if !$!{'ESRCH'};
+            last;
+        };
+
+        Time::HiRes::sleep(0.1);
+    }
+
+    if (!$reaped) {
+        diag "Done sending SIG$SIG; waiting …";
+
+        waitpid $pid, 0;
+    }
+
+    diag "Finished waiting.";
 
     return;
 }
@@ -102,9 +135,13 @@ sub post_bind_hook {
 sub process_http_request {
     my $self = shift;
 
-    print $MyServer::HEAD;
-
     my $uri_path = $ENV{'PATH_INFO'};
 
+    local $| = 1;
+
+    print $MyServer::HEAD_START;
+    print "X-URI: $uri_path$CRLF";
+    print $CRLF;
+
     print( $uri_path eq '/biggie' ? $MyServer::BIGGIE : $uri_path );
 }
